@@ -1,5 +1,5 @@
 density_joint <-
-function(x,y,mu,delta,lambda,theta,family){
+function(x,y,mu,delta,lambda,theta,family,zt=TRUE){
     if (length(mu)!=length(lambda)) stop("mu and lambda must be of the same length")
     u<-pgam(x,mu,delta)
     u[u>=1]=1
@@ -7,13 +7,19 @@ function(x,y,mu,delta,lambda,theta,family){
     u[is.na(u)]=0
     u[u==-Inf]=0
     u[u==Inf]=1
-    v<-pztp(y,lambda)
+    if (zt==TRUE){
+        v<-pztp(y,lambda)
+        vv<-pztp(y-1,lambda)
+    }
+    if (zt==FALSE){
+        v<-ppois(y,lambda)
+        vv<-ppois(y-1,lambda)
+    }
     v[v>=1]=1
     v[v<0]=0
     v[is.na(v)]=0
     v[v==-Inf]=0
     v[v==Inf]=1
-    vv<-pztp(y-1,lambda)
     vv[vv>=1]=1
     vv[vv<0]=0
     vv[is.na(vv)]=0
@@ -24,7 +30,12 @@ function(x,y,mu,delta,lambda,theta,family){
     par_der<-D_u(u,v,theta,family)
     par_der1=D_u(u,vv,theta,family)
     dummy<-par_der - par_der1
-    dummy[y==1]=par_der[y==1]
+    if (zt==TRUE){
+        dummy[y==1]=par_der[y==1]
+    }
+    if (zt==FALSE){
+        dummy[y==0]=par_der[y==0]
+    }
     # multiply with density of X
     out<-marginal.x*dummy
     return(out)
