@@ -9,15 +9,20 @@ predict.copreg=function(object,Rtest,Stest,exposure=rep(1,nrow(Stest)),independe
 	x.pred<-as.vector(exp(Rtest%*%a$alpha))
 	lambda<-as.vector(exp(Stest%*%a$beta))*exposure
 	mu<-as.vector(exp(Rtest%*%a$alpha))
-	y.pred<-lambda/(1-exp(-lambda))
+    if (a$zt==TRUE){
+	   y.pred<-lambda/(1-exp(-lambda))
+    }
+    if (a$zt==FALSE){
+    y.pred=lambda
+    }
 	l.pred.ifm<-NULL
     if (independence==TRUE){
         l.pred<-x.pred*y.pred
-	l.pred.ifm<-epolicy_loss(mu,a$delta,lambda,a$theta.ifm,a$family0)
+	#l.pred.ifm<-epolicy_loss(mu,a$delta,lambda,a$theta.ifm,a$family0,a$zt)
     }
     else{
-	l.pred<-epolicy_loss(mu,a$delta,lambda,a$theta,a$family)}
-	return(list(x.pred=x.pred,y.pred=y.pred,l.pred=l.pred,l.pred.ifm=l.pred.ifm))
+	l.pred<-epolicy_loss(mu,a$delta,lambda,a$theta,a$family,zt=a$zt)}
+	return(list(x.pred=x.pred,y.pred=y.pred,l.pred=l.pred))
 
 
 }
